#!/bin/bash

# Функция для вывода помощи
usage() {
  echo "Использование: $0 [-back] input.pdf"
  exit 1
}

# Проверка наличия аргумента для PDF файла
if [ -z "$1" ]; then
  usage
fi

# Значения по умолчанию
include_next_page=false

# Обработка опций
while [[ $# -gt 0 ]]; do
  case "$1" in
    -back)
      include_next_page=true
      ;;
    -*)
      usage
      ;;
    *)
      pdf_file="$1"
      ;;
  esac
  shift
done

# Проверка наличия PDF файла
if [ -z "$pdf_file" ]; then
  usage
fi

# Определение пути к txt файлу на основе имени pdf файла
txt_file="${pdf_file%.pdf}.txt"

# Проверка наличия txt файла
if [ ! -f "$txt_file" ]; then
  echo "Ошибка: Файл '$txt_file' не найден."
  exit 1
fi

# Файл для логирования
log_file="script.log"

# Очистка старого файла лога
> "$log_file"

# Функция для логирования
log() {
  echo "$(date '+%Y-%m-%d %H:%M:%S') - $1" >> "$log_file"
}

# Переменная для хранения страниц, которые нужно извлечь
pages_to_extract=""

# Чтение файла построчно
while IFS= read -r search_string; do 
  # Удаление возможных лишних символов
  search_string=$(echo "$search_string" | tr -d '\r\n')
  
  log "Ищем строку: '$search_string'"
  
  # Извлечение номера страницы
  page_number=$(pdfgrep -n -m 1 "$search_string" "$pdf_file" | cut -d: -f1)
  
  log "Найдена страница: '$page_number'"
  
  # Если страница найдена, добавляем её в список
  if [[ $page_number ]]; then
    pages_to_extract="${pages_to_extract}${page_number} "
    
    # Если аргумент -back задан, добавляем следующую страницу
    if $include_next_page; then
      next_page_number=$((page_number + 1))
      pages_to_extract="${pages_to_extract}${next_page_number} "
      log "Добавляем также следующую страницу: '$next_page_number'"
    fi
  else
    log "Строка '$search_string' не найдена в файле '$pdf_file'"
  fi
  
done < "$txt_file"

# Если есть страницы для извлечения, извлекаем их
if [ -n "$pages_to_extract" ]; then
  output_file="extracted_pages.pdf"
  pdftk "$pdf_file" cat $pages_to_extract output "$output_file"
  log "Извлеченные страницы сохранены в файл $output_file"
else
  log "Не найдено страниц для извлечения"
fi
